@@ -24,18 +24,13 @@ import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
 
+from google.cloud.metastore_v1beta import gapic_version as package_version
 from google.cloud.metastore_v1beta.types import metastore
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-dataproc-metastore",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 class DataprocMetastoreTransport(abc.ABC):
@@ -49,12 +44,13 @@ class DataprocMetastoreTransport(abc.ABC):
         self,
         *,
         host: str = DEFAULT_HOST,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -82,11 +78,6 @@ class DataprocMetastoreTransport(abc.ABC):
                 be used for service account credentials.
         """
 
-        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
-        if ":" not in host:
-            host += ":443"
-        self._host = host
-
         scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
         # Save the scopes.
@@ -107,6 +98,11 @@ class DataprocMetastoreTransport(abc.ABC):
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
+            # Don't apply audience if the credentials file passed from user.
+            if hasattr(credentials, "with_gdch_audience"):
+                credentials = credentials.with_gdch_audience(
+                    api_audience if api_audience else host
+                )
 
         # If the credentials are service account credentials, then always try to use self signed JWT.
         if (
@@ -119,6 +115,11 @@ class DataprocMetastoreTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
+        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
+        if ":" not in host:
+            host += ":443"
+        self._host = host
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -197,6 +198,26 @@ class DataprocMetastoreTransport(abc.ABC):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
+            self.remove_iam_policy: gapic_v1.method.wrap_method(
+                self.remove_iam_policy,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.query_metadata: gapic_v1.method.wrap_method(
+                self.query_metadata,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.move_table_to_database: gapic_v1.method.wrap_method(
+                self.move_table_to_database,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.alter_metadata_resource_location: gapic_v1.method.wrap_method(
+                self.alter_metadata_resource_location,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
     def close(self):
@@ -353,6 +374,45 @@ class DataprocMetastoreTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def remove_iam_policy(
+        self,
+    ) -> Callable[
+        [metastore.RemoveIamPolicyRequest],
+        Union[
+            metastore.RemoveIamPolicyResponse,
+            Awaitable[metastore.RemoveIamPolicyResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def query_metadata(
+        self,
+    ) -> Callable[
+        [metastore.QueryMetadataRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def move_table_to_database(
+        self,
+    ) -> Callable[
+        [metastore.MoveTableToDatabaseRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def alter_metadata_resource_location(
+        self,
+    ) -> Callable[
+        [metastore.AlterMetadataResourceLocationRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def kind(self) -> str:
         raise NotImplementedError()
