@@ -32,12 +32,11 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
     """gRPC backend transport for DataprocMetastore.
 
     Configures and manages metastore services. Metastore services are
-    fully managed, highly available, auto-scaled, auto-healing,
-    OSS-native deployments of technical metadata management software.
-    Each metastore service exposes a network endpoint through which
-    metadata queries are served. Metadata queries can originate from a
-    variety of sources, including Apache Hive, Apache Presto, and Apache
-    Spark.
+    fully managed, highly available, autoscaled, autohealing, OSS-native
+    deployments of technical metadata management software. Each
+    metastore service exposes a network endpoint through which metadata
+    queries are served. Metadata queries can originate from a variety of
+    sources, including Apache Hive, Apache Presto, and Apache Spark.
 
     The Dataproc Metastore API defines the following resource model:
 
@@ -69,14 +68,14 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
         self,
         *,
         host: str = "metastore.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        channel: grpc.Channel = None,
-        api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        channel: Optional[grpc.Channel] = None,
+        api_mtls_endpoint: Optional[str] = None,
+        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
@@ -204,8 +203,8 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
     def create_channel(
         cls,
         host: str = "metastore.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
         **kwargs,
@@ -612,7 +611,7 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
     ) -> Callable[[metastore.CreateBackupRequest], operations_pb2.Operation]:
         r"""Return a callable for the create backup method over gRPC.
 
-        Creates a new Backup in a given project and location.
+        Creates a new backup in a given project and location.
 
         Returns:
             Callable[[~.CreateBackupRequest],
@@ -658,6 +657,121 @@ class DataprocMetastoreGrpcTransport(DataprocMetastoreTransport):
             )
         return self._stubs["delete_backup"]
 
+    @property
+    def remove_iam_policy(
+        self,
+    ) -> Callable[
+        [metastore.RemoveIamPolicyRequest], metastore.RemoveIamPolicyResponse
+    ]:
+        r"""Return a callable for the remove iam policy method over gRPC.
+
+        Removes the attached IAM policies for a resource
+
+        Returns:
+            Callable[[~.RemoveIamPolicyRequest],
+                    ~.RemoveIamPolicyResponse]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "remove_iam_policy" not in self._stubs:
+            self._stubs["remove_iam_policy"] = self.grpc_channel.unary_unary(
+                "/google.cloud.metastore.v1beta.DataprocMetastore/RemoveIamPolicy",
+                request_serializer=metastore.RemoveIamPolicyRequest.serialize,
+                response_deserializer=metastore.RemoveIamPolicyResponse.deserialize,
+            )
+        return self._stubs["remove_iam_policy"]
+
+    @property
+    def query_metadata(
+        self,
+    ) -> Callable[[metastore.QueryMetadataRequest], operations_pb2.Operation]:
+        r"""Return a callable for the query metadata method over gRPC.
+
+        Query DPMS metadata.
+
+        Returns:
+            Callable[[~.QueryMetadataRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "query_metadata" not in self._stubs:
+            self._stubs["query_metadata"] = self.grpc_channel.unary_unary(
+                "/google.cloud.metastore.v1beta.DataprocMetastore/QueryMetadata",
+                request_serializer=metastore.QueryMetadataRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["query_metadata"]
+
+    @property
+    def move_table_to_database(
+        self,
+    ) -> Callable[[metastore.MoveTableToDatabaseRequest], operations_pb2.Operation]:
+        r"""Return a callable for the move table to database method over gRPC.
+
+        Move a table to another database.
+
+        Returns:
+            Callable[[~.MoveTableToDatabaseRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "move_table_to_database" not in self._stubs:
+            self._stubs["move_table_to_database"] = self.grpc_channel.unary_unary(
+                "/google.cloud.metastore.v1beta.DataprocMetastore/MoveTableToDatabase",
+                request_serializer=metastore.MoveTableToDatabaseRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["move_table_to_database"]
+
+    @property
+    def alter_metadata_resource_location(
+        self,
+    ) -> Callable[
+        [metastore.AlterMetadataResourceLocationRequest], operations_pb2.Operation
+    ]:
+        r"""Return a callable for the alter metadata resource
+        location method over gRPC.
+
+        Alter metadata resource location. The metadata
+        resource can be a database, table, or partition. This
+        functionality only updates the parent directory for the
+        respective metadata resource and does not transfer any
+        existing data to the new location.
+
+        Returns:
+            Callable[[~.AlterMetadataResourceLocationRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "alter_metadata_resource_location" not in self._stubs:
+            self._stubs[
+                "alter_metadata_resource_location"
+            ] = self.grpc_channel.unary_unary(
+                "/google.cloud.metastore.v1beta.DataprocMetastore/AlterMetadataResourceLocation",
+                request_serializer=metastore.AlterMetadataResourceLocationRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["alter_metadata_resource_location"]
+
     def close(self):
         self.grpc_channel.close()
 
